# This package contains macros that provide functionality relating to
# Software Collections. These macros are not used in default
# Fedora builds, and should not be blindly copied or enabled.
# Specifically, the "scl" macro must not be defined in official Fedora
# builds. For more information, see:
# http://docs.fedoraproject.org/en-US/Fedora_Contributor_Documentation/1/html/Software_Collections_Guide/index.html

%{?scl:%scl_package rubygem-%{gem_name}}
%{!?scl:%global pkg_name %{name}}

%global gem_name foreman_openscap

%global foreman_dir /usr/share/foreman
%global foreman_bundlerd_dir %{foreman_dir}/bundler.d

Name: %{?scl_prefix}rubygem-%{gem_name}
Version: 0.5.3.19
Release: 1%{?foremandist}%{?dist}
Summary: Foreman plug-in for displaying OpenSCAP audit reports
Group: Applications/System
License: GPLv3
URL: https://github.com/OpenSCAP/foreman_openscap
Source0: http://satellite6.lab.eng.rdu2.redhat.com/pub/sources/6.2/%{gem_name}-%{version}.gem

Requires: foreman >= 1.11.0

Requires: scap-security-guide
Requires: %{?scl_prefix_ruby}ruby(release)
Requires: %{?scl_prefix_ruby}ruby(rubygems)
Requires: %{?scl_prefix}rubygem(deface) < 2.0
Obsoletes: %{?scl_prefix}rubygem(scaptimony) < 0.3.2-3

BuildRequires: gettext
BuildRequires: %{?scl_prefix_ruby}ruby(release)
BuildRequires: %{?scl_prefix_ruby}rubygems-devel
BuildRequires: %{?scl_prefix_ruby}rubygems
BuildRequires: foreman-assets >= 1.7.0
BuildRequires: foreman-plugin >= 1.8.0
BuildRequires: %{?scl_prefix}rubygem(deface) < 2.0

BuildArch: noarch
Provides: %{?scl_prefix}rubygem(%{gem_name}) = %{version}
Provides: foreman-plugin-openscap
%{?scl:Obsoletes: ruby193-rubygem-%{gem_name}}

%description
Foreman plug-in for managing security compliance reports.


%package doc
Summary: Documentation for %{name}
Group: Documentation
Requires: %{?scl_prefix}%{pkg_name} = %{version}-%{release}
%{?scl:Obsoletes: ruby193-rubygem-%{gem_name}-doc}
BuildArch: noarch

%description doc
Documentation for %{name}.

%prep
%{?scl:scl enable %{scl} "}
gem unpack %{SOURCE0}
%{?scl:"}

%setup -q -D -T -n  %{gem_name}-%{version}
mkdir -p .%{gem_dir}
%{?scl:scl enable %{scl} "}
gem install --local --install-dir .%{gem_dir} \
            --force %{SOURCE0} --no-rdoc --no-ri
%{?scl:"}

%build

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

#build locale files
pushd %{buildroot}/%{gem_instdir}
make -C locale all-mo
popd

mkdir -p %{buildroot}%{foreman_bundlerd_dir}

%foreman_bundlerd_file
%foreman_precompile_plugin -s

%files
%dir %{gem_instdir}
%{gem_libdir}
%{gem_instdir}/app
%{gem_instdir}/db
%{gem_instdir}/config
%{gem_instdir}/locale
%exclude %{gem_cache}
%{gem_spec}
%{foreman_bundlerd_plugin}
%doc %{gem_instdir}/LICENSE
%{foreman_assets_plugin}

%exclude %{gem_instdir}/test

%files doc
%doc %{gem_instdir}/LICENSE
%doc %{gem_instdir}/README.md

%posttrans
# We need to run the db:migrate (because of SCAPtimony) after the install transaction
%foreman_db_migrate
/usr/sbin/foreman-rake db:seed  >/dev/null 2>&1 || :
/usr/sbin/foreman-rake apipie:cache  >/dev/null 2>&1 || :
%foreman_restart
exit 0

%changelog
* Fri Mar 17 2017 zjhuntin <zhunting@redhat.com> 0.5.3.19-1
- 

* Tue Aug 30 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.18-1
- BZ #1365299 - After upgrade "undefined method 'name' for nil:NilClass" when visiting dashboard (oscap widget

* Thu Jul 21 2016 Zach Huntington-Meath <zhunting@redhat.com> 0.5.3.17-1
- BZ #1358287 - cannot download in xml bzip or view full reports of older compliance reports from sat6.1 migratio

* Wed Jul 20 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.16-1
- BZ #1358287 - cannot download in xml bzip or view full reports of older compliance reports from sat6.1 migratio

* Wed Jul 13 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.15-1
- BZ #1353436 - \[upgrade] db migrate failed with error: undefined local variable or method 'openscap_proxy_id

* Mon Jun 27 2016 Zach Huntington-Meath <zhunting@redhat.com> 0.5.3.14-1
- BZ #1334035 - Unable to delete SCAP reports or delete a HOST if it has SCAP reports presen

* Wed Jun 15 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.13-2
- Add missing locale file to foreman_openscap (ericdhelms@gmail.com)

* Wed Jun 15 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.13-1
- BZ #1345751 - \[ALL LANG] Unlocalized strings in Hosts -> SCAP contents

* Wed Jun 15 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.12-1
- BZ #1345751 - \[ALL LANG] Unlocalized strings in Hosts -> SCAP contents.
- BZ #1313846 - selecting the Oscap_Proxy throws TypeError as seen from Firebu

* Thu May 26 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.11-1
- BZ #1337920 - Pull in the translations for snap 13

* Wed May 25 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.9-1
- BZ #1336928 - unable to view compliance report

* Mon May 23 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.8-1
- BZ #1336928 - unable to view compliance report

* Mon May 16 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.7-1
- BZ #1335664 - Pull in the translations for snap 12.

* Tue May 03 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.5-1
- BZ #1317261 - Migration of SCAP from Sat 6.1 to Sat 6.

* Mon Apr 11 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.4-1
- BZ #1322990 - compliance report searches fail

* Tue Mar 29 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.3-1
- BZ #1314354 - unable to select oscap XCCDF profile while creating a policy

* Tue Mar 22 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.2-1
- 

* Sat Mar 12 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.1-1
- 

* Sat Feb 20 2016 Eric D Helms <ericdhelms@gmail.com> 0.5.3.0-1
- foreman_openscap 0.5.3 (shlomi@ben-hanna.com)

* Wed Jan 27 2016 Chris Peters <chrispeters.psu@gmail.com> 0.5.2-2
- new package built with tito

* Thu Dec 24 2015 Dominic Cleal <dcleal@redhat.com> 0.5.2-2
- Replace ruby(abi) for ruby22 rebuild (dcleal@redhat.com)

* Thu Dec 10 2015 Dominic Cleal <dcleal@redhat.com> 0.5.2-1
- foreman_openscap version 0.5.2 (shlomi@ben-hanna.com)

* Mon Nov 02 2015 Dominic Cleal <dcleal@redhat.com> 0.5.0-1
- foreman_openscap 0.5.0 (shlomi@ben-hanna.com)
- Remove Scaptimony (shlomi@ben-hanna.com)

* Thu Aug 27 2015 Dominic Cleal <dcleal@redhat.com> 0.4.3-2
- Converted to tfm SCL (dcleal@redhat.com)

* Thu Aug 20 2015 Dominic Cleal <dcleal@redhat.com> 0.4.3-1
- Release foreman_openscap 0.4.3 (shlomi@ben-hanna.com)

* Fri Aug 14 2015 Dominic Cleal <dcleal@redhat.com> 0.4.2-1
- foreman_openscap 0.4.2 (shlomi@ben-hanna.com)
- Better branched builds with Foreman version macro (dcleal@redhat.com)

* Tue May 12 2015 Dominic Cleal <dcleal@redhat.com> 0.4.1-1
- foreman_openscap 0.4.1 (shlomi@ben-hanna.com)

* Wed Mar 25 2015 Šimon Lukašík <slukasik@redhat.com> - 0.4.0-1
- new upstream release

* Thu Mar 19 2015 Šimon Lukašík <slukasik@redhat.com> - 0.3.3-1
- new upstream release

* Mon Mar 02 2015 Šimon Lukašík <slukasik@redhat.com> - 0.3.2-1
- new upstream release
- fix FTBFS, missing foreman-plugins dep for build macros (dcleal@redhat.com)

* Thu Feb 12 2015 Šimon Lukašík <slukasik@redhat.com> - 0.3.1-1
- new upstream release

* Wed Jan 28 2015 Šimon Lukašík <slukasik@redhat.com> - 0.3.0-1
- new upstream release

* Fri Jan 23 2015 Marek Hulán <mhulan@redhat.com> - 0.2.1-1
- new upstream release

* Thu Dec 04 2014 Šimon Lukašík <slukasik@redhat.com> - 0.2.0-1
- new upstream release

* Thu Oct 23 2014 Šimon Lukašík <slukasik@redhat.com> - 0.1.0-1
- rebuilt

* Mon Jul 28 2014 Šimon Lukašík <slukasik@redhat.com> - 0.0.1-1
- Initial package
